@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -214,7 +214,7 @@ class TpuAsyncClient:
     ) -> pagers.ListNodesAsyncPager:
         r"""Lists nodes.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -312,7 +312,7 @@ class TpuAsyncClient:
     ) -> cloud_tpu.Node:
         r"""Gets the details of a node.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -400,7 +400,7 @@ class TpuAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a node.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -521,7 +521,7 @@ class TpuAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a node.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -622,7 +622,7 @@ class TpuAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Reimages a node's OS.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -703,7 +703,7 @@ class TpuAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Stops a node.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -784,7 +784,7 @@ class TpuAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Starts a node.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -866,7 +866,7 @@ class TpuAsyncClient:
     ) -> pagers.ListTensorFlowVersionsAsyncPager:
         r"""List TensorFlow versions supported by this API.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -964,7 +964,7 @@ class TpuAsyncClient:
     ) -> cloud_tpu.TensorFlowVersion:
         r"""Gets TensorFlow Version.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -1052,7 +1052,7 @@ class TpuAsyncClient:
     ) -> pagers.ListAcceleratorTypesAsyncPager:
         r"""Lists accelerator types supported by this API.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -1150,7 +1150,7 @@ class TpuAsyncClient:
     ) -> cloud_tpu.AcceleratorType:
         r"""Gets AcceleratorType.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
