@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -449,8 +449,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> pagers.ListNodesPager:
         r"""Lists nodes.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -548,8 +547,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> cloud_tpu.Node:
         r"""Gets the details of a node.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -637,8 +635,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> operation.Operation:
         r"""Creates a node.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -759,8 +756,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> operation.Operation:
         r"""Deletes a node.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -861,8 +857,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> operation.Operation:
         r"""Reimages a node's OS.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -944,8 +939,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> operation.Operation:
         r"""Stops a node.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -1027,8 +1021,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> operation.Operation:
         r"""Starts a node.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -1111,8 +1104,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> pagers.ListTensorFlowVersionsPager:
         r"""List TensorFlow versions supported by this API.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -1212,8 +1204,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> cloud_tpu.TensorFlowVersion:
         r"""Gets TensorFlow Version.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -1301,8 +1292,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> pagers.ListAcceleratorTypesPager:
         r"""Lists accelerator types supported by this API.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
@@ -1400,8 +1390,7 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> cloud_tpu.AcceleratorType:
         r"""Gets AcceleratorType.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import tpu_v1
 
